Class: Webring::Generators::CustomWidgetControllerGenerator
- Inherits:
-
Rails::Generators::Base
- Object
- Rails::Generators::Base
- Webring::Generators::CustomWidgetControllerGenerator
- Includes:
- Shared::RouteInjector
- Defined in:
- lib/generators/webring/custom_widget_controller/custom_widget_controller_generator.rb
Overview
Note:
This generator should be run after installing the Webring engine
This generator creates both the controller file and adds the required routes